# WMO Weather Codes

| Code | Description |
|------|-------------|
| 0 | Clear sky |
| 1-3 | Mainly clear, partly cloudy, overcast |
| 45, 48 | Fog, depositing rime fog |
| 51-55 | Drizzle (light, moderate, dense) |
| 61-65 | Rain (slight, moderate, heavy) |
| 71-75 | Snowfall (slight, moderate, heavy) |
| 80-82 | Rain showers (slight, moderate, violent) |
| 95 | Thunderstorm |
| 96, 99 | Thunderstorm with hail |
